@@ -439,8 +439,8 @@ class VirtualArray(awkward.array.base.AwkwardArray):
     def flatten(self, axis=0):
         return self._util_flatten(self.array, axis)
 
-    def pad(self, length, maskedwhen=True, clip=False):
-        return self._util_pad(self.array, length, maskedwhen, clip)
+    def pad(self, length, maskedwhen=True, clip=False, axis=0):
+        return self._util_pad(self.array, length, maskedwhen, clip, axis)
 
     def regular(self):
         return self._util_regular(self.array)
